@@ -1,11 +1,14 @@
 """
-The "public" properties on the cb module
+Client for the Calcbench API
 
-"""
-__version__ = "5.11.0"
-from datetime import datetime
+To turn on verbose logging
 import logging
 import sys
+logger = logging.getLogger()
+logging.getLogger('calcbench').setLevel(logging.DEBUG)
+logger.addHandler(logging.StreamHandler(stream=sys.stdout))
+"""
+__version__ = "5.6.1"
 from .api_client import (
     as_reported_raw,
     business_combinations,
@@ -54,24 +57,4 @@ from .business_combinations import (
     legacy_report as business_combination_legacy_report,
 )
 
-from .press_release import press_release_raw, press_release_data
-
-
-def turn_on_logging(level=logging.DEBUG, timezone="US/Eastern", add_handler=False):
-    """
-    Turn on verbose logging
-
-    """
-    import pytz
-
-    logging.Formatter.converter = lambda *args: datetime.now(
-        tz=pytz.timezone(timezone)
-    ).timetuple()
-    logging.basicConfig(
-        format="%(asctime)s.%(msecs)03d %(levelname)-8s %(message)s", datefmt="%H:%M:%S"
-    )
-    cb_logger = logging.getLogger("calcbench")
-    cb_logger.setLevel(level)
-    if add_handler:
-        cb_logger.addHandler(logging.StreamHandler(stream=sys.stdout))
-    return cb_logger
\ No newline at end of file
+from .press_release import press_release_raw, press_release_data
\ No newline at end of file
